@@ -6,18 +6,18 @@ import os
 # from flask import flash
 # from flask import request
 from flask import Blueprint
-from flask import current_app
 from flask import render_template
-from flask import redirect
-from flask import url_for
 
 #
-# from shopyoapi.html import notify_success
-# from shopyoapi.forms import flash_errors
-from shopyoapi.enhance import get_active_theme_dir
-from shopyoapi.enhance import get_setting
+# from shopyo.api.html import notify_success
+# from shopyo.api.forms import flash_errors
+# from shopyo.api.enhance import get_active_theme_dir
+# from shopyo.api.enhance import get_setting
 
-from modules.shop.helpers import get_cart_data
+# from modules.box__ecommerce.shop.helpers import get_cart_data
+
+
+from modules.box__default.settings.helpers import get_setting
 
 dirpath = os.path.dirname(os.path.abspath(__file__))
 module_info = {}
@@ -41,11 +41,10 @@ module_blueprint = globals()["{}_blueprint".format(module_info["module_name"])]
 def index():
     # cant be defined above but must be manually set each time
     # active_theme_dir = os.path.join(
-    #     dirpath, "..", "..", "themes", get_setting("ACTIVE_THEME")
+    #     dirpath, "..", "..", "themes", get_setting("ACTIVE_FRONT_THEME")
     # )
     # module_blueprint.template_folder = active_theme_dir
 
     # return str(module_blueprint.template_folder)
 
-    return redirect(url_for("shop.homepage"))
-
+    return render_template(get_setting("ACTIVE_FRONT_THEME") + "/index.html")
